.\" $Xorg: synaptics.man,v 1.0 2003/11/14 18:20:58 vojta Exp $
.\" shorthand for double quote that works everywhere.
.ds q \N'34'
.TH SYNAPTICS __drivermansuffix__ __vendorversion__
.SH NAME
synaptics \- Synaptics touchpad driver
.SH SYNOPSIS
.B "Section \*qInputDevice\*q"
.br
.BI "  Identifier \*q" idevname \*q
.br
.B  "  Driver \*qsynaptics\*q"
.br
.BI "  Option \*qDevice\*q   \*q" devpath \*q
.br
\ \ ...
.br
.B EndSection
.SH DESCRIPTION
.B synaptics 
is an __xservername__ input driver for Synaptics touchpads.
.PP
The
.B synaptics
driver functions as a pointer input device, and may be used as the
X server's core pointer.
.SH SUPPORTED HARDWARE
The
.B synaptics
driver supports Synaptics PS/2 touchpads, based primarily on the Version 4.5
touchpad.  With this touchpad, there are two mouse buttons, mapped to buttons
1 and 3, and also (optionally) a pair of rocker buttons used to emulate a
wheel mouse.  The touchpad is run in absolute mode, allowing all of these
features to be supported (if enabled by the relevant configuration options).
.SH CONFIGURATION DETAILS
Please refer to __xconfigfile__(__filemansuffix__) for general configuration
details and for options that can be used with all input drivers.  This
section only covers configuration details specific to the
.B synaptics
driver.
.PP
In the following list, the following consideration applies to all values that
specify a unit of time.  Times are specified in milliseconds.  The value given
must be an integer.  Because the Synaptics touchpad reports events at a
uniform rate of 80 or 40 packets per second, time values have a granularity
of 12.5 or 25 ms.  Time values should not be set to an exact multiple of this
interval, though, since then a timeout would occur at the same time as a
packet would arrive, leading to inconsistent behavior depending on whether the
timeout occurred before or after the expected packet arrived.  Instead,
time values should be set to a value that is slightly larger than a
multiple of the time between packets.
.PP
The following driver options are supported:
.TP 7
.BI "Option \*qDevice\*q \*q" string \*q
Specifies the device through which the mouse can be accessed.  A common
setting is "/dev/mouse", which is often a symbolic link to the real
device.  This option is optional.  The default value depends on the
protocol in use.  With the
.B psaux
protocol, the default value for the
.B Device
option is
.BR /dev/psaux .
With the
.B event
protocol, the default value is probed, and is of the form
.BR /dev/input/event\fInn\fP .
.TP 7
.BI "Option \*qProtocol\*q \*q" string \*q
The
.B Protocol
option sets the protocol that the
.B synaptics
driver uses to communicate with the touchpad.  Usually only one protocol
is available on a system, depending on its operating system kernel.
Valid values for the
.B Protocol
option are as follows.
.TS
l l.
auto-dev	automatically detect the protocol (default)
psaux	raw events
event	Linux input subsystem events (kernel 2.6 and higher)
psm	FreeBSD psm driver (not currently implemented)
.TE
.TP 7
.BI "Option \*qEnabled\*q \*q" boolean \*q
Determines whether the touchpad is to be enabled or not.  Usually this should
be selected, but the touchpad may be turned off (typically using the control
program
.BR synclient )
if a different pointing device is in use.  Default: on.
.TP 7
.BI "Option \*qEmulate3Buttons\*q \*q" boolean \*q
Enable/disable the emulation of the third (middle) mouse button by pressing
both mouse buttons simultaneously.  In addition, the left or right mouse button
can be shown as pressed while the middle mouse button is down, by releasing
and pressing that mouse button while keeping the other button pressed.
(This feature is the same as that provided by the standard
.B mouse
driver.)  Default: off.
.TP 7
.BI "Option \*qEmulate3Timeout\*q \*q" integer \*q
Sets the timeout (in milliseconds) that the driver waits before deciding
if two buttons were pressed "simultaneously" when three-button emulation is
enabled.
Default: 55.
.TP 7
.BI "Option \*qTapToClick\*q \*q" boolean \*q
Causes a tap on the touchpad to indicate a click on mouse button 1.
Default: off.
.TP 7
.BI "Option \*qTapAndDrag\*q \*q" boolean \*q
Causes a tap on the touchpad, followed soon by a drag, to indicate mouse motion
with button 1 pressed.
Selecting this option also automatically selects
.BR TapToClick .
Default: off.
.TP 7
.BI "Option \*qTapButton1\*q \*q" integer \*q
Indicates which button to click in case of a tap gesture with one finger,
not located in a corner.  This option has no effect unless
.B TapToClick
(or
.BR TapAndDrag )
is selected.  If set to zero, then such taps will have no effect.
Default: 1.
.TP 7
.BI "Option \*qTapButton2\*q \*q" integer \*q
Indicates which button to click in case of a tap gesture with two fingers.
This option has no effect unless
.B TapToClick
(or
.BR TapAndDrag )
is selected.  If set to zero, then such taps will have no effect.
Default: 2.
.TP 7
.BI "Option \*qTapButton3\*q \*q" integer \*q
Indicates which button to click in case of a tap gesture with three fingers.
This option has no effect unless
.B TapToClick
(or
.BR TapAndDrag )
is selected.  If set to zero, then such taps will have no effect.
Default: 3.
.TP 7
.BI "Option \*qULCornerButton\*q \*q" integer \*q
Indicates which button to click in case of a tap in the upper left-hand corner
of the touchpad.  This option has no effect unless
.B TapToClick
(or
.BR TapAndDrag )
is selected.  If set to zero, then such taps will be treated as if they did
not occur in a corner.
Default: 0.
.TP 7
.BI "Option \*qURCornerButton\*q \*q" integer \*q
Similar to the
.B ULCornerButton
option, but applies to taps in the upper right-hand corner.
Default: 0.
.TP 7
.BI "Option \*qLLCornerButton\*q \*q" integer \*q
Similar to the
.B ULCornerButton
option, but applies to taps in the lower left-hand corner.
Default: 0.
.TP 7
.BI "Option \*qLRCornerButton\*q \*q" integer \*q
Similar to the
.B ULCornerButton
option, but applies to taps in the lower right-hand corner.
Default: 0.
.TP 7
.BI "Option \*qHighRate\*q \*q" boolean \*q
Sets the touchpad to send 80 data packets per second instead of 40.
This option is only operative when the touchpad is being accessed in raw
mode; otherwise its data rate is determined by the operating system kernel.
Default: on.
.TP 7
.BI "Option \*qEdgeMotionUseAlways\*q \*q" boolean \*q
If one has selected
.B TapAndDrag
and the finger reaches the edge of the touchpad while a tap-and-drag operation
is taking place, the driver will continue to send events indicating that
the cursor is moving in the direction appropriate for the edge(s) that the
finger is close to.  This option enables this behavior also when the finger
nears the edge of the pad and no tap-and-drag gesture is being handled.
Default: off.
.TP 7
.BI "Option \*qRightEdgeScroll\*q \*q" boolean \*q
If selected, finger motion along the right edge of the touchpad will be
interpreted as a vertical scroll action, which is encoded as button 4 and 5
events.  Scrolling stops if the finger leaves the edge region.
Default: off.
.TP 7
.BI "Option \*qLeftEdgeScroll\*q \*q" boolean \*q
Same as
.BR RightEdgeScroll ,
except that it uses the left edge of the scrollpad.
Default: off.
.TP 7
.BI "Option \*qBottomEdgeScroll\*q \*q" boolean \*q
If selected, finger motion along the bottom edge of the touchpad will be
interpreted as a horizontal scroll action, which is encoded as button 6 and 7
events.  Scrolling stops if the finger leaves the edge region.
Default: off.
.TP 7
.BI "Option \*qTopEdgeScroll\*q \*q" boolean \*q
Same as
.BR BottomEdgeScroll ,
except that it uses the top edge of the scrollpad.
Default: off.
.TP 7
.BI "Option \*qVertTwoFingerScroll\*q \*q" boolean \*q
If selected, vertical motion of two fingers on the touchpad is interpreted
as vertical scrolling, and sent as button 4 and 5 events.
Default: off.
.TP 7
.BI "Option \*qHorizTwoFingerScroll\*q \*q" boolean \*q
If selected, horizontal motion of two fingers on the touchpad is interpreted
as horizontal scrolling, and sent as button 6 and 7 events.
Default: off.
.TP 7
.BI "Option \*qMaxTapTime\*q \*q" integer \*q
If
.B TapToClick
is selected, indicates the maximum time (in milliseconds) that the finger
should be pressing on the pad for the driver to interpret the gesture as a tap.
Default: 180.
.TP 7
.BI "Option \*qTapDuration\*q \*q" integer \*q
If
.B TapToClick
is selected, this indicates how long the driver will indicate that the button
is held down for a simple tap.  (If the
.B TapAndDrag
option is selected, then tap and drag operations will of course involve the
button being asserted for longer periods of time.  Also, double and triple
taps may shorten the time that the button is asserted.)
Default: 155.
.TP 7
.BI "Option \*qHorizScrollDelta\*q \*q" integer \*q
If the
.B BottomEdgeScroll
or
.B TopEdgeScroll
option is selected, this option determines how many mouse units of motion
should correspond to each button 6 or 7 scroll event.
Default: 20.
.TP 7
.BI "Option \*qVertScrollDelta\*q \*q" integer \*q
If the
.B LeftEdgeScroll
or
.B RightEdgeScroll
option is selected, this option determines how many mouse units of motion
should correspond to each button 4 or 5 scroll event.
Default: 20.
.TP 7
.BI "Option \*qFingerHigh\*q \*q" integer \*q
This option specifies the amount of pressure (in units determined by the
touchpad hardware) needed before the finger is counted as being pressed down
(in a tapping or dragging motion).
Default: 29.
.TP 7
.BI "Option \*qFingerLow\*q \*q" integer \*q
This option specifies the amount of pressure (in units determined by the
touchpad hardware) below which the finger is counted as being lifted from
the pad (at the end of a tapping or dragging operation).
Default: 20.
.TP 7
.BI "Option \*qEdgeMotionMinZ\*q \*q" integer \*q
When the finger is at the edge of the touchpad and cursor motion is to result
from that proximity, the speed of the cursor motion can be determined by
the amount of pressure exerted on the finger.  If the pressure is as indicated
by this option, or smaller, then the speed of the cursor is as indicated by
the
.B EdgeMotionMinSpeed
option.  As the pressure is increased to that given by the
.B EdgeMotionMaxZ
option, the speed increases to that given by the
.B EdgeMotionMaxSpeed
option.
Default: 50.
.TP 7
.BI "Option \*qEdgeMotionMaxZ\*q \*q" integer \*q
See the discussion under
.BR EdgeMotionMinZ .
Default: 100.
.TP 7
.BI "Option \*qEdgeMotionMinSpeed\*q \*q" integer \*q
See the discussion under the
.B EdgeMotionMinZ
option.
Default: 24.
.TP 7
.BI "Option \*qEdgeMotionMaxSpeed\*q \*q" integer \*q
See the discussion under the
.B EdgeMotionMinZ
option.
Default: 90.
.PP
Some touchpad features involve dividing up the touchpad into regions,
corresponding to either edges or corners.  Each such purpose has its own
set of four options for setting the boundaries of the edge or corner regions
in question.  These options should be set to a decimal value between 0 and 1,
where 0 corresponds to a region of zero width at the given edge and 1
corresponds to a region comprising the whole touchpad.  These values are
rounded to the nearest multiple of 1/255.
.PP
The first four geometry options determine the boundaries of edges for the
purpose of edge-motion features.  If the finger enters one of these edge
regions during a tap-and-drag operation (if
.B TapAndDrag
is selected), or at any other time
(if
.B EdgeMotionUseAlways
is selected), then the mouse pointer continues moving in a direction determined
by which edge(s) the finger is close to.
.TP 7
.BI "Option \*qMotionPosLeft\*q \*q" float \*q
Determines the width of the region at the left edge for edge-motion features.
Default: 0.039
.TP 7
.BI "Option \*qMotionPosRight\*q \*q" float \*q
Determines the width of the region at the right edge for edge-motion features.
Default: 0.039
.TP 7
.BI "Option \*qMotionPosTop\*q \*q" float \*q
Determines the height of the region at the top edge for edge-motion features.
Default: 0.051
.TP 7
.BI "Option \*qMotionPosBottom\*q \*q" float \*q
Determines the height of the region at the bottom edge for edge-motion features.
Default: 0.051
.PP
Edge scrolling (as determined by the
.BR LeftEdgeScroll ,
.BR RightEdgeScroll ,
.BR TopEdgeScroll ,
and
.B BottomEdgeScroll
options) uses the options
.BR ScrollPosLeft ,
.BR ScrollPosRight ,
.BR ScrollPosTop ,
and
.B ScrollPosBottom
to determine the size of the region along the edge.  These again are
.I float
values between 0 and 1, valid to the nearest multiple of 1/255 and interpreted
as above.  Their default values are 0.059 for
.B ScrollPosLeft
and
.BR ScrollPosRight ,
and 0.082 for
.B ScrollPosTop
and
.BR ScrollPosBottom .
.PP
The
.BR CornerPosLeft ,
.BR CornerPosRight ,
.BR CornerPosTop ,
and
.B CornerPosBottom
options determine the boundaries of the corner regions of the touchpad, as
used by the
.BR ULCornerButton ,
.BR URCornerButton ,
.BR LLCornerButton ,
and
.B LRCornerButton
options.  For example, the boundaries of the lower right-hand corner are
determined by the
.B CornerPosRight
and
.B CornerPosBottom
options.  As with other position options, the values of these options are
.I float
values between 0 and 1, valid to the nearest multiple of 1/255 and interpreted
similarly to the
.BR MotionPosLeft ,
etc. options.  Their default values are 0.082 for
.B CornerPosLeft
and
.BR CornerPosRight ,
0.110 for
.BR CornerPosTop ,
and 0.102 for
.BR CornerPosBottom .
.SH SEE ALSO
synconfig(__appmansuffix__), __xservername__(__appmansuffix__), __xconfigfile__(__filemansuffix__), xorgconfig(__appmansuffix__), Xserver(__appmansuffix__), X(__miscmansuffix__).
.SH AUTHORS
This driver was originally written by Paul Vojta.
.\" Other contributors include:
